@@ -1,13 +1,13 @@
 package Array::Iterator;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-09'; # DATE
-our $DIST = 'Array-Iterator'; # DIST
-our $VERSION = '0.130'; # VERSION
-
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-26'; # DATE
+our $DIST = 'Array-Iterator'; # DIST
+our $VERSION = '0.131'; # VERSION
+
 ### constructor
 
 sub new {
@@ -126,16 +126,16 @@ sub next {
 }
 
 sub get_next {
-	my ($self) = @_;
-        $self->{_iterated} = 1;
-    return undef unless ($self->{_current_index} < $self->{_length});
-	return $self->_getItem($self->{_iteratee}, $self->{_current_index}++);
+    my ($self) = @_;
+    $self->{_iterated} = 1;
+    return undef unless ($self->{_current_index} < $self->{_length}); ## no critic: Subroutines::ProhibitExplicitReturnUndef
+    return $self->_getItem($self->{_iteratee}, $self->{_current_index}++);
 }
 
 sub getNext { my $self = shift; $self->get_next(@_) }
 
 sub peek {
-	my ($self, $n) = @_;
+    my ($self, $n) = @_;
 
     if(not defined $n) { $n = 1 }
     elsif(not $n)      { die "peek(0) doesn't make sense, did you mean get_next()?" }
@@ -143,8 +143,8 @@ sub peek {
 
     my $idx = $self->{_current_index} + ($n - 1);
 
-    return undef unless ($idx < $self->{_length});
-	return $self->_getItem($self->{_iteratee}, $idx);
+    return undef unless ($idx < $self->{_length}); ## no critic: Subroutines::ProhibitExplicitReturnUndef
+    return $self->_getItem($self->{_iteratee}, $idx);
 }
 
 sub current {
@@ -181,7 +181,7 @@ Array::Iterator - A simple class for iterating over Perl arrays
 
 =head1 VERSION
 
-This document describes version 0.130 of Array::Iterator (from Perl distribution Array-Iterator), released on 2021-08-09.
+This document describes version 0.131 of Array::Iterator (from Perl distribution Array-Iterator), released on 2021-09-26.
 
 =head1 SYNOPSIS
 
@@ -445,14 +445,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Array-Iter
 
 Source repository is at L<https://github.com/perlancar/perl-Array-Iterator>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Array-Iterator>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 This module now includes several subclasses of Array::Iterator which add certain behaviors
@@ -488,7 +480,7 @@ stevan little, E<lt>stevan@iinteractive.comE<gt>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexey Surikov Mohammad S Anwar Neil Bowers Steven Haryanto (on PC)
+=for stopwords Alexey Surikov Florian Schlichting Mohammad S Anwar Neil Bowers Steven Haryanto (on PC)
 
 =over 4
 
@@ -498,6 +490,10 @@ Alexey Surikov <ksurent@gmail.com>
 
 =item *
 
+Florian Schlichting <fsfs@debian.org>
+
+=item *
+
 Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =item *
@@ -510,6 +506,23 @@ Steven Haryanto (on PC) <stevenharyanto@gmail.com>
 
 =back
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2021, 2017, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
@@ -526,4 +539,12 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Array-Iterator>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
